@@ -75,8 +75,15 @@ class Cmarg00(BlockFile):
         Tabela com os custos marginais por patamar, por série e
         por mês/ano de estudo.
 
+        - Ano (`int`)
+        - Série (`int`)
+        - Patamar (`str`)
+        - Janeiro (`float`)
+        - ...
+        - Dezembro (`float`)
+
         :return: A tabela dos custos marginais por patamar.
-        :rtype: Optional[pd.DataFrame]
+        :rtype: pd.DataFrame | None
         """
         if self.__cmargs is None:
             self.__cmargs = self.__monta_tabela()
